"{ Encoding: utf8 }"

"{ Package: 'stx:goodies/regression' }"

"{ NameSpace: RegressionTests }"

TestCase subclass:#OperatingSystemTest
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'tests-Regression-RuntimeSystem'
!


!OperatingSystemTest methodsFor:'constants'!

targetFile
    |baseName|

    baseName := 'lsOut'.

    OperatingSystem isMSDOSlike ifTrue:[
        ^ Filename homeDirectory "ensure write permission" / baseName  
    ].
    OperatingSystem isUNIXlike ifTrue:[
        ^ '/tmp' asFilename / baseName  
    ].

    self notYetImplemented
! !

!OperatingSystemTest methodsFor:'helpers'!

helperActorStreamWithCommand:aCommand
    |targetFile expected outStr errStr exitStatus|

    OperatingSystem isMSDOSlike ifFalse:[
        ^ self
    ].

    targetFile := self targetFile.

    OperatingSystem executeCommand:aCommand, ' > ', targetFile pathName.
    expected := targetFile contentsOfEntireFile.

    outStr := ActorStream new.
    outStr nextPutLineBlock:[:line | Transcript normal; showCR:line ].
    errStr := ActorStream new.
    outStr nextPutLineBlock:[:line | Transcript bold; showCR:line ].

    OperatingSystem
        executeCommand:aCommand
        inputFrom:nil
        outputTo:outStr
        errorTo:errStr
        inDirectory:nil
        lineWise:true
        onError:[:status | exitStatus := status].
!

helperCommandOutput1WithCommand:aCommand
    |targetFile expected outStr errStr exitStatus|

    targetFile := self targetFile.

    OperatingSystem executeCommand:aCommand, ' > ', targetFile pathName.
    expected := targetFile contentsOfEntireFile.

    1 to:50 do:[:counter |
"/ Transcript show:counter; showCR:':'.
        outStr := '' writeStream.
        errStr := '' writeStream.
        OperatingSystem
            executeCommand:aCommand
            inputFrom:nil
            outputTo:outStr
            errorTo:errStr
            onError:[:status | exitStatus := status].
        self assert:(outStr contents = expected).
        self assert:(errStr contents isEmpty).
        self assert:(exitStatus isNil).
    ].
!

helperCommandOutput2WithCommand:aCommand
    |outStr errStr exitStatus|

    1 to:50 do:[:counter |
"/ Transcript show:counter; showCR:':'.
        outStr := '' writeStream.
        errStr := '' writeStream.
        OperatingSystem
            executeCommand:aCommand
            inputFrom:nil
            outputTo:outStr
            errorTo:errStr
            onError:[:status | exitStatus := status].
        self assert:(outStr contents isEmpty).
        self assert:(errStr contents notEmpty).
        self assert:(exitStatus success not).
        self assert:(exitStatus stillAlive not).
        self assert:(exitStatus couldNotExecute not).
    ].
! !

!OperatingSystemTest methodsFor:'release'!

tearDown
    self targetFile delete.
! !

!OperatingSystemTest methodsFor:'tests'!

testActorStream
    OperatingSystem isMSDOSlike ifTrue:[
        self helperActorStreamWithCommand:'dir'. 
        ^ self
    ].
    OperatingSystem isUNIXlike ifTrue:[
        self helperActorStreamWithCommand:'ls'.
        ^ self             
    ].

    self notYetImplemented

    "
        self new testActorStream
    "
!

testCommandOutput1
    OperatingSystem isMSDOSlike ifTrue:[
        self helperCommandOutput1WithCommand:'dir /b'. "/ /b print just filenames, because the filesize differs...
        ^ self
    ].
    OperatingSystem isUNIXlike ifTrue:[
        self helperCommandOutput1WithCommand:'ls'.
        ^ self             
    ].

    self notYetImplemented

    "
        self new testCommandOutput1
    "
!

testCommandOutput2
    OperatingSystem isMSDOSlike ifTrue:[
        self helperCommandOutput2WithCommand:'dir /fooBar'. 
        ^ self
    ].
    OperatingSystem isUNIXlike ifTrue:[
        self helperCommandOutput2WithCommand:'ls /fooBar'.
        ^ self             
    ].

    self notYetImplemented

    "
        self new testCommandOutput2
    "
!

testInvalidCommand
    |outStr errStr exitStatus|

    1 to:50 do:[:counter |
"/ Transcript show:counter; showCR:':'.
	outStr := '' writeStream.
	errStr := '' writeStream.
	OperatingSystem
	    executeCommand:'blabla /fooBar'
	    inputFrom:nil
	    outputTo:outStr
	    errorTo:errStr
	    onError:[:status | exitStatus := status].
	self assert:(exitStatus success not).
	self assert:(exitStatus stillAlive not).
	self assert:(exitStatus couldNotExecute).
	self assert:(outStr contents isEmpty).
	self assert:(errStr contents notEmpty).
    ].

    "
     self new testInvalidCommand
    "
! !

!OperatingSystemTest class methodsFor:'documentation'!

version
    ^ '$Header$'
!

version_CVS
    ^ '$Header$'
! !

